@@ -8,7 +8,7 @@
 heuristicC<-function(data){
 	gram=data%*%t(data)
 	n=dim(gram)[1]
-	kxixi=matrix(ncol=n,nr=1)
+	kxixi=matrix(ncol=n,nrow=1)
 	for(i in 1:n){
 		kxixi[1,i]=sqrt(gram[i,i])
 	}
